import React from 'react';
import { Flex, FlexItem } from '@huawei/react-weui';
import Page from '../../component/page';
import Accordion from '../../component/accordion';

import IconForm from './images/icon_nav_form.png';
import IconFeedback from './images/icon_nav_feedback.png';
import IconLayout from './images/icon_nav_layout.png';
import IconNav from './images/icon_nav_nav.png';
import IconSearch from './images/icon_nav_search.png';
import IconZIndex from './images/icon_nav_z-index.png';
import openNewView from '../../../utils/openNewView';

import './index.less';

const menus = [
  {
    name: 'View',
    icon: IconZIndex,
    items: [
      {
        label: 'Swiper',
        to: '/swiper'
      },
      {
        label: 'Page',
        to: '/page'
      }
    ]
  },
  {
    name: 'Form',
    icon: IconForm,
    items: [
      {
        label: 'Button',
        to: '/button'
      },
      {
        label: 'List',
        to: '/list'
      },
      {
        label: 'Input',
        to: '/input'
      },
      {
        label: 'Picker',
        to: '/picker'
      },
      {
        label: 'Slider',
        to: '/slider'
      },
      {
        label: 'Uploader',
        to: '/uploader'
      }
    ]
  },
  {
    name: 'Basic Components',
    icon: IconLayout,
    items: [
      {
        label: 'Article',
        to: '/article'
      },
      {
        label: 'Badge',
        to: '/badge'
      },
      {
        label: 'Flex',
        to: '/flex'
      },
      {
        label: 'Footer',
        to: '/footer'
      },
      {
        label: 'Gallery',
        to: '/gallery'
      },
      {
        label: 'Grid',
        to: '/grid'
      },
      {
        label: 'Icons',
        to: '/icons'
      },
      {
        label: 'Loadmore',
        to: '/loadmore'
      },
      {
        label: 'Panel',
        to: '/panel'
      },
      {
        label: 'Preview',
        to: '/preview'
      },
      {
        label: 'Progress',
        to: '/progress'
      }
    ]
  },
  {
    name: 'Feedbacks',
    icon: IconFeedback,
    items: [
      {
        label: 'Actionsheet',
        to: '/actionsheet'
      },
      {
        label: 'Dialog',
        to: '/dialog'
      },
      {
        label: 'Msg',
        to: '/msg'
      },
      // {
      //   label: 'Toast',
      //   to: '/toast'
      // },
      {
        label: 'Toptips',
        to: '/toptips'
      },
      {
        label: 'Popup',
        to: '/popup'
      },
      {
        label: 'Pull To Refresh',
        to: '/ptr'
      },
      {
        label: 'Infinite Loader',
        to: '/infinite'
      }
    ]
  },
  {
    name: 'Navigations',
    icon: IconNav,
    items: [
      {
        label: 'Navbar',
        to: '/navbar'
      },
      {
        label: 'Tabbar',
        to: '/tabbar'
      },
      {
        label: 'AutoNavbar',
        to: '/navbar2'
      },
      {
        label: 'AutoTabbar',
        to: '/tabbar2'
      }
    ]
  },
  {
    name: 'Search',
    icon: IconSearch,
    items: [
      {
        label: 'Search Bar',
        to: '/searchbar'
      }
    ]
  }
];
const subTitle = (
  <div className="home-jsapi">
    A UI library by WeChat official design team,
    includes the most useful widgets/modules in mobile web applications.
    <br />
    ## 相关链接<br />
    <a onClick={() => openNewView('h5://welink.h5demo/html/index.html')} href="javascript:void(0)">h5mo</a>
    <br />
    <a onClick={() => openNewView('/jsapi')} href="javascript:void(0)">WeLink JSAPI Demo</a>
  </div>
);
const Home = (props) => (
  <Page
    className="home"
    title="WeUI"
    subTitle={subTitle}
    spacing
  >
    <ul>
      {menus.map((menu, i) => (
        <li key={i}>
          <Accordion
            header={
              <Flex>
                <FlexItem component="p">
                  {menu.name}
                </FlexItem>
                <img
                  src={menu.icon}
                  alt=""
                />
              </Flex>
            }
          >
            <div className="weui-cells">
              {menu.items.map((item, j) => (
                <a key={`${i}-${j}`} className="weui-cell weui-cell_access" onClick={() => { openNewView(item.to); }} href="javascript:void(0)">
                  <div className="weui-cell__bd">{item.label}</div>
                  <div className="weui-cell__ft" />
                </a>
              ))}
            </div>
          </Accordion>
        </li>
      ))}
    </ul>
  </Page>
);

export default Home;
